***sample analysis: UK company risks***
***Big Data for Policy Conference, Cambridge, UK, 17/6/2015
***Mihly Fazekas (University of Cambridge, DIGIWHIST project)
*************************************************************************

use "D:\Munka\Kzbeszerzs\kb_adatok_2010\data\elemzesi adatbazis\UK_local_CRI2015\UK_firm_sample_150613.dta", clear

***INTUITION: check out larges winners in 2009h1 and 2013h2***
gsort +yh -sum_ls_org
by yh: gen yhrank=_n
gen x=.
replace x=supid if yhrank<=5 & yh==98
egen y=max(x), by(supid)
gen z=.
replace z=supid if yhrank<=5 & yh==107
egen w=max(z), by(supid)
*marking 5 largest companies in 2009h1 (best=1) and 2013h2 (best=2)
gen best=0
replace best=1 if supid==y
replace best=2 if supid==w
drop x y z w

xtline sum_ls_org if best==1, ylabel(10(2)24) xlabel(#10, angle(vertical)) ytitle("log contract value won") overlay
xtline sum_ls_org if best==2, ylabel(10(2)24) xlabel(#10, angle(vertical)) ytitle("log contract value won") overlay

***EXPLORING TWO INFAMOUS COMPANIES: check out "capita plc" (3652) and "g4s" (8174)**
xtline sum_ls_org if supid==3653 | supid==8174, ylabel(10(2)20) xlabel(#10, angle(vertical)) ytitle("log contract value won") overlay

***GAUGING SYSTEMIC RISKS: regression analysis***
xtreg sum_ls_org lag_sum_ls_org lsum_s_mainm ib45.mainm, re
predict lresid, ue

egen x=mean(lresid) if per3e==0, by(supid)
egen alresid1=max(x), by(supid)
drop x
egen x=mean(lresid) if per3e==2, by(supid)
egen alresid2=max(x), by(supid)
drop x
twoway (scatter alresid2 alresid1)(lfit alresid2 alresid1), xlabel(-5(2.5)5) ylabel(-5(2.5)5) legend(off) ytitle("alresid2")
***some companies have suspicious error term patterns: a) top left, b)bottom right

egen x=mean(cri_c_org) if per3e==0, by(supid)
egen acri_c_org1=max(x), by(supid)
drop x
egen x=mean(cri_c_org) if per3e==2, by(supid)
egen acri_c_org2=max(x), by(supid)
drop x

twoway (scatter acri_c_org2 acri_c_org1)(function y = x, range(0 0.45)) if alresid2>0 & alresid1<0, xlabel(0(0.1)0.45) ylabel(0(0.1)0.45) legend(off) ytitle("acri_c_org2") xtitle("acri_c_org1")
***some companies with suspicious CRI pattens on top of suspicious winning patterns

***LINKING SYSTEMIC TO INFAMOUS COMPANIES: back to  "capita plc" (3652) and "g4s" (8174)***
xtline lresid if supid==3653 | supid==8174, ylabel(-5(2.5)5) xlabel(#10, angle(vertical)) ytitle("residual log contract value won") overlay
xtline cri_c_org if supid==3653 | supid==8174, ylabel(0(0.1)0.6) xlabel(#10, angle(vertical)) ytitle("CRI") overlay
tabstat cri_c_org if supid==3653, by(per3e) stat(mean p50 N)
tabstat cri_c_org if supid==8174, by(per3e) stat(mean p50 N)
